Before you post an issue, please check the following (if applicable):

* Read [this FAQ](https://jitcde-common.readthedocs.io/#common-mistakes-and-questions).

* Provide [a minimal and complete example](https://stackoverflow.com/help/mcve). In particular consider that I cannot know what control parameters you are using. It makes my life considerably easier and you will likely get a helpful answer earlier. Also, there is a chance that you will solve your problem yourself.

* State your JiTC\*DE version (`jitcode.__version__` or similar). If it’s reasonably possible for you, try updating to the newest version first, in particular if yours is still smaller than 1.0.
